@@ -84,6 +84,23 @@ class RiakTestCase1(unittest.TestCase):
 
         log.msg("done secondary_index")
 
+    @defer.inlineCallbacks
+    def test_set_data_empty(self):
+        """Get an object that does not exist, then set_data and save it """
+        log.msg("*** set_data_empty")
+
+        obj = yield self.bucket.get("foo1") 
+
+        self.assertEqual(obj.exists(), False)
+        self.assertEqual(obj.get_data(), None)
+
+        obj.set_data('bar1')
+        yield obj.store()
+
+        self.assertEqual(obj.exists(), True)
+        self.assertEqual(obj.get_data(), "bar1")
+        log.msg("done set_data_empty")
+
     @defer.inlineCallbacks
     def test_add_and_delete(self):
         """Basic adds and deletes"""
@@ -517,10 +534,12 @@ class RiakTestCase1(unittest.TestCase):
         # so there's now something wrong with link storage.
         log.msg('*** store_and_get_links')
 
+        quote_string = "tag2!@#%^&*)"
+
         obj = self.bucket.new("foo", 2) \
                 .add_link(self.bucket.new("foo1")) \
                 .add_link(self.bucket.new("foo2"), "tag") \
-                .add_link(self.bucket.new("foo3"), "tag2!@#%^&*)")
+                .add_link(self.bucket.new(quote_string), quote_string)
         yield obj.store()
         del obj
 
@@ -528,6 +547,11 @@ class RiakTestCase1(unittest.TestCase):
         obj = yield self.bucket.get("foo")
         links = obj.get_links()
         self.assertEqual(len(links), 3)
+
+        quote_link = links[-1]
+        self.assertEqual(quote_link.get_key(), quote_string)
+        self.assertEqual(quote_link.get_tag(), quote_string)
+
         log.msg('done store_and_get_links')
 
     @defer.inlineCallbacks
